@@ -64,7 +64,7 @@ active_class <- R6::R6Class(
       target <- pipeline_get_target(self$pipeline, name)
       target_debug(target)
       target_update_depend(target, self$pipeline, self$meta)
-      trn(
+      if_any(
         target_should_run(target, self$meta),
         self$run_target(name),
         self$skip_target(target)
