@@ -34,10 +34,10 @@ parallel_class <- R6::R6Class(
       counter_del_names(counter, head)
       head
     },
-    enqueue = function(names, ranks = NULL) {
+    prepend = function(names, ranks = NULL) {
       new_ranks <- ranks %|||% rep(0L, length(names))
-      ranks <- c(self$get_ranks(), new_ranks)
-      names <- c(self$get_names(), names)
+      ranks <- c(new_ranks, self$get_ranks())
+      names <- c(names, self$get_names())
       names(ranks) <- names
       self$data <- ranks
       counter <- self$counter
