@@ -35,13 +35,15 @@ reporter_class <- R6::R6Class(
     },
     report_started = function(target = NULL, progress = NULL) {
     },
-    report_skipped = function(target, progress) {
+    report_built = function(target = NULL, progress = NULL) {
+    },
+    report_skipped = function(target = NULL, progress = NULL) {
     },
     report_errored = function(target = NULL, progress = NULL) {
     },
     report_canceled = function(target = NULL, progress = NULL) {
     },
-    report_outdated = function(checked, outdated) {
+    report_outdated = function(outdated) {
     },
     report_workspace = function(target) {
     },
