@@ -1,5 +1,6 @@
 #' @title Reconstruct the branch names and the names of their dependencies.
 #' @export
+#' @family branching
 #' @description Given a branching pattern, use available metadata
 #'   to reconstruct branch names and the names of each
 #'   branch's dependencies. The metadata of each target
@@ -35,7 +36,7 @@ tar_branches <- function(name, pattern) {
   name <- deparse_language(substitute(name))
   assert_chr(name, "name arg of tar_target() must be a symbol")
   assert_store()
-  assert_path(file.path("_targets/meta/meta"))
+  assert_path(file.path(path_meta()))
   pattern <- as.expression(substitute(pattern))
   deps <- all.vars(pattern, functions = FALSE, unique = TRUE)
   vars <- c(name, deps)
@@ -72,7 +73,7 @@ tar_branches <- function(name, pattern) {
 tar_branches_nibling <- function(x, meta) {
   children <- unname(unlist(meta[meta$name == x, "children"]))
   assert_nonempty(children, paste(x, "has no children."))
-  assert_nonmissing(children, paste(x, "has no children."))
+  assert_none_na(children, paste(x, "has no children."))
   out <- data_frame(x = children)
   colnames(out) <- x
   out
