@@ -313,17 +313,17 @@ tar_test("database$validate()", {
 
 tar_test("database$validate() with bad list columns", {
   out <- database_init(header = c("name", "a"), list_columns = "b")
-  expect_error(out$validate(), class = "condition_validate")
+  expect_error(out$validate(), class = "tar_condition_validate")
 })
 
 tar_test("database$validate() without name column", {
   out <- database_init(header = letters)
-  expect_error(out$validate(), class = "condition_validate")
+  expect_error(out$validate(), class = "tar_condition_validate")
 })
 
 
 tar_test("validate compatible header", {
-  tar_script()
+  tar_script(list())
   tar_make(callr_function = NULL)
   data <- tar_meta()
   meta <- meta_init()
@@ -338,7 +338,7 @@ tar_test("do not validate header of missing file", {
 })
 
 tar_test("fail to validate incompatible header", {
-  tar_script()
+  tar_script(list())
   tar_make(callr_function = NULL)
   data <- tar_meta()
   data$size <- NULL
@@ -346,6 +346,6 @@ tar_test("fail to validate incompatible header", {
   meta$database$overwrite_storage(data)
   expect_error(
     tar_make(callr_function = NULL),
-    class = "condition_file"
+    class = "tar_condition_file"
   )
 })
