@@ -30,7 +30,10 @@ tar_test("bad compression level throws error", {
       )
     )
   })
-  expect_error(tar_make(callr_function = NULL), class = "condition_validate")
+  expect_error(
+    tar_make(callr_function = NULL),
+    class = "tar_condition_validate"
+  )
 })
 
 tar_test("fst packages", {
@@ -38,3 +41,20 @@ tar_test("fst packages", {
   out <- store_get_packages(x$store)
   expect_equal(out, "fst")
 })
+
+tar_test("does not inherit from tar_external", {
+  store <- tar_target(x, "x_value", format = "fst")$store
+  expect_false(inherits(store, "tar_external"))
+})
+
+tar_test("store_row_path()", {
+  store <- tar_target(x, "x_value", format = "fst")$store
+  store$file$path <- "path"
+  expect_equal(store_row_path(store), NA_character_)
+})
+
+tar_test("store_path_from_record()", {
+  store <- tar_target(x, "x_value", format = "fst")$store
+  record <- record_init(name = "x", path = "path", format = "fst")
+  expect_equal(store_path_from_record(store, record), path_objects("x"))
+})
